Slash
=====


|                       |                                                                                    |
|-----------------------|------------------------------------------------------------------------------------|
| Build Status          | ![Build Status](https://secure.travis-ci.org/getslash/slash.png?branch=master,dev) |
| Supported Versions    | ![Supported Versions](https://img.shields.io/badge/python-2.7%2C3.3%2C3.4%2C3.5%2C3.6-green.svg)    |
| Latest Version        | ![Latest Version](https://img.shields.io/pypi/v/slash.svg)                  |
| Test Coverage         | ![Coverage Status](https://img.shields.io/coveralls/getslash/slash/develop.svg)   |




Slash is a testing framework written in Python for testing complex projects. 

* [Homepage](http://getslash.github.io/slash)

* [Documentation](https://slash.readthedocs.org/)
